@@ -46,7 +46,7 @@ class TestClientInterface:
 
         with pytest.raises(NotImplementedError):
             # use with multiprocessing
-            var_azc.read(mp=True).csv(path=path)
+            var_azc.glob("https://testazfs.queue.core.windows.net/test_queue/test/*.msg")
 
     def test_azfs_input_error(self, var_azc):
         with pytest.raises(AzfsInputError):
